/******************************************************************************
* To the extent possible under law, Sebastian Roith
* <https://www.roith-unterrichtet.de> has waived all copyright and related or
* neighboring rights to this script. This work is published from Germany.
******************************************************************************/

/**
* Klasse, die ein nummerisches Attribut ein- und auslesen kann
*/
function AttributeBoolean(
    attributeName,      // Attributname
    required            // Optional: Muss dieses Attribut angegeben sein?
) {
    Object.defineProperty(this, 'attributeName', { 'value': attributeName, 'enumerable': true });
    if (required)
        this.required = true;
}

// Attributname
AttributeBoolean.prototype.attributeName = 'an';

// Muss dieses Attribut angegeben sein?
AttributeBoolean.prototype.required = false;

// Standardwert
AttributeBoolean.prototype.defaultValue = false;

/**
* Zum zugehörigen Attributwert in obj die Bezeichnung ermitteln
* @return String        Bezeichnung des Werts (false, wenn kein Attributwert angegeben)
*/
AttributeBoolean.prototype.nameValue = function(
    obj     // Objekt mit den Attributwerten
) {
    var value = obj[this.attributeName];
    if (value === undefined)
        return false;
    return value ? 'ja' : 'nein';
}

/**
* Den zur Angabe strKey passenden Attributwert im Objekt obj eintragen
* @return String        Im Fehlerfall Fehlermeldung
*/
AttributeBoolean.prototype.readValue = function(
    strKey,     // Von Benutzer eingegebener Wert, der tatsächlichen Attributwert beschreibt
    obj         // Objekt für tatsächliche Attributwerte
) {
    var noValue = (strKey === undefined) || (strKey === false) || !strKey.length;
    if (noValue && this.required)
        return 'Wert ' + (this.attributeName ? ('des Attributs „' + this.attributeName + '“ ') : '') + 'fehlt';
    if (noValue) {
        obj[this.attributeName] = this.defaultValue;
        return;
    }
    var lowercase = strKey.toLowerCase();
    if (['ja', 'true', 'wahr'].indexOf(lowercase) != -1) {
        obj[this.attributeName] = true;
        return;
    }
    if (['nein', 'false', 'falsch'].indexOf(lowercase) != -1) {
        obj[this.attributeName] = false;
        return;
    }
    return  'Ungültiger Wert „' + strKey + (this.attributeName ? ('“ für boolsches Attribut „' + this.attributeName) : '') + '“ (Nur „ja“ und „nein“ sind erlaubt)';
}
