/******************************************************************************
* To the extent possible under law, Sebastian Roith
* <https://www.roith-unterrichtet.de> has waived all copyright and related or
* neighboring rights to this script. This work is published from Germany.
******************************************************************************/

/**
* Klasse, die ein nummerisches Attribut ein- und auslesen kann
*/
function AttributeNumber(
    attributeName,      // Attributname
    minValue,           // Kleinster erlaubter Wert
    maxValue,           // Größter erlaubter Wert
    digits,             // Anzahl an Nachkommastellen
    required            // Optional: Muss dieses Attribut angegeben sein?
) {
    Object.defineProperty(this, 'attributeName', { 'value': attributeName, 'enumerable': true });
    this.minValue = minValue;
    this.maxValue = maxValue;
    this.digits = digits;
    if (required)
        this.required = true;
}

// Attributname
AttributeNumber.prototype.attributeName = 'zahl';

// Kleinster erlauber Wert
AttributeNumber.prototype.minValue = -Infinity;

// Größter erlauber Wert
AttributeNumber.prototype.maxValue = Infinity;

// Anzahl an Nachkommastellen
AttributeNumber.prototype.digits = 0;

// Muss dieses Attribut angegeben sein?
AttributeNumber.prototype.required = false;

// Standardwert
AttributeNumber.prototype.defaultValue = 0;

/**
* Zum zugehörigen Attributwert in obj die Bezeichnung ermitteln
* @return String        Bezeichnung des Werts (false, wenn kein Attributwert angegeben)
*/
AttributeNumber.prototype.nameValue = function(
    obj     // Objekt mit den Attributwerten
) {
    var value = obj[this.attributeName];
    if (value === undefined)
        return false;
    return ('' + value).replace('.', ',');
}

/**
* Den zur Angabe strKey passenden Attributwert im Objekt obj eintragen
* @return String        Im Fehlerfall Fehlermeldung
*/
AttributeNumber.prototype.readValue = function(
    strKey,     // Von Benutzer eingegebener Wert, der tatsächlichen Attributwert beschreibt
    obj         // Objekt für tatsächliche Attributwerte
) {
    var noValue = (strKey === undefined) || (strKey === false) || !strKey.length;
    if (noValue && this.required)
        return 'Wert ' + (this.attributeName ? ('des Attributs „' + this.attributeName + '“ ') : '') + 'fehlt';
    if (noValue) {
        obj[this.attributeName] = this.defaultValue;
        return;
    }
    var number = +strKey.replace(',', '.');
    if (!Number.isFinite(number))
        return  'Ungültiger Wert „' + strKey + (this.attributeName ? ('“ für Attribut „' + this.attributeName) : '') + '“ (Nur Zahlen sind erlaubt)';
    if (number < this.minValue)
        return  'Wert „' + strKey + (this.attributeName ? ('“ für Attribut „' + this.attributeName) : '') + '“ ist zu klein (Mindestwert ' + ('' + this.minValue).replace('.', ',') + ')';
    if (number > this.maxValue)
        return  'Wert „' + strKey + (this.attributeName ? ('“ für Attribut „' + this.attributeName) : '') + '“ ist zu groß (Maximalwert ' + ('' + this.maxValue).replace('.', ',') + ')';
    if (Number.isFinite(this.digits)) {
        var stufenzahl = Math.pow(10, this.digits);
        number = Math.round(number * stufenzahl) / stufenzahl;
    }
    obj[this.attributeName] = number;
    return;
}
