/******************************************************************************
* To the extent possible under law, Sebastian Roith
* <https://www.roith-unterrichtet.de> has waived all copyright and related or
* neighboring rights to this script. This work is published from Germany.
******************************************************************************/

/**
* Klasse, um aus einem Objekt mit tatsächlichen Attributwerten einen entsprechenden DOM-Knoten zu machen
*/
function ParagraphNodeBuilder() {
}

/**
* Erstellt einen DOM-Knoten anhand von Attributwerten
* @return HTMLElement   Erstellter DOM-Knoten
*/
ParagraphNodeBuilder.prototype.create = function(
    atts        // Objekt mit den tatsächlichen Attributwerten
) {
    var r = Math.min(atts.breite, atts.hoehe) / 2 * atts.abrundung;
    var p = ScoTools.createHtml('p', undefined, null, 'Dies ist ein unheimlich langer Text, damit du besser beobachten kannst, was die Auswirkung der von dir angegebenen Attributwerte ist. Hast du eigentlich schon verstanden, was alle Attribute bewirken? Wenn nicht, dann unbedingt ausprobieren. Los jetzt!');
    if (atts.ausrichtung !== undefined)
        p.style.textAlign = atts.ausrichtung;
    if (atts.abstandOben)
        p.style.marginTop = atts.abstandOben + 'mm';
    if (atts.abstandUnten)
        p.style.marginBottom = atts.abstandUnten + 'mm';
    if (atts.einzugLinks)
        p.style.marginLeft = atts.einzugLinks + 'mm';
    if (atts.einzugRechts)
        p.style.marginRight = atts.einzugRechts + 'mm';
    if (atts.einzugErsteZeile !== undefined)
        p.style.textIndent = (atts.einzugErsteZeile - (atts.einzugLinks ? atts.einzugLinks : 0)) + 'mm';
    if (atts.zeilenhoehe)
        p.style.lineHeight = atts.zeilenhoehe;
    if (atts.fett)
        p.style.fontWeight = 'bold';
    if (atts.kursiv)
        p.style.fontStyle = 'italic';
    if (atts.unterstrichen)
        p.style.textDecoration = 'underline';
    if (atts.kapitaelchen)
        p.style.fontVariant = 'small-caps';
    if (atts.hintergrund)
        p.style.backgroundColor = atts.hintergrund;
    return p;
}

/**
* Erstellt einen DOM-Knoten anhand von Attributwerten und ersetzt nodeOld durch den neu erstellten Knoten bzw. fügt ihn am Ende von parentNode ein
* @return SVGElement    Erstellter DOM-Knoten
*/
ParagraphNodeBuilder.prototype.change = function(
    atts,       // Objekt mit den tatsächlichen Attributwerten
    nodeOld,    // Zu ersetzender DOM-Knoten
    parentNode  // Übergeordneter DOM-Knoten
) {
    var node = this.create(atts);
    if (nodeOld && nodeOld.parentNode)
        nodeOld.parentNode.replaceChild(node, nodeOld);
    else
        parentNode.appendChild(node);
    return node;
}
